package com.vctgo.system.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.vctgo.system.api.domain.SysReLocationArea;

import java.util.List;
import java.util.Map;

/**
 * 位置与区域关联Service接口
 *
 * @author caesar
 * @date 2023-05-30
 */
public interface ISysReLocationAreaService extends IService<SysReLocationArea>
{
    /**
     * 查询位置与区域关联
     *
     * @param id 位置与区域关联主键
     * @return 位置与区域关联
     */
    SysReLocationArea selectSysReLocationAreaById(Long id);

    /**
     * 查询位置与区域关联列表-分页
     *
     * @param sysReLocationArea 位置与区域关联
     * @return 位置与区域关联集合
     */
    IPage<SysReLocationArea> selectSysReLocationAreaPage(SysReLocationArea sysReLocationArea);
    /**
     * 查询位置与区域关联列表
     *
     * @param sysReLocationArea 位置与区域关联
     * @return 位置与区域关联集合
     */
    List<SysReLocationArea> selectSysReLocationAreaList(SysReLocationArea sysReLocationArea);

    /**
     * 根据相应参数查询是否存在该区域
     *
     * @param params 参数
     * @return 区域设置集合
     */
    List<SysReLocationArea> selectRelInfoListByParams(Map<String, Object> params);

    /**
     * 新增位置与区域关联
     *
     * @param sysReLocationArea 位置与区域关联
     * @return 结果
     */
    int insertSysReLocationArea(SysReLocationArea sysReLocationArea);

    /**
     * 修改位置与区域关联
     *
     * @param sysReLocationArea 位置与区域关联
     * @return 结果
     */
    int updateSysReLocationArea(SysReLocationArea sysReLocationArea);

    /**
     * 批量删除位置与区域关联
     *
     * @param ids 需要删除的位置与区域关联主键集合
     * @return 结果
     */
    int deleteSysReLocationAreaByIds(Long[] ids);

    /**
     * 删除位置与区域关联信息
     *
     * @param id 位置与区域关联主键
     * @return 结果
     */
    int deleteSysReLocationAreaById(Long id);
}
